summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--NEWS5
-rw-r--r--cmds.py12
-rw-r--r--exporter.py14
3 files changed, 19 insertions, 12 deletions
diff --git a/NEWS b/NEWS
index fc6b85b..3926888 100644
--- a/NEWS
+++ b/NEWS
@@ -12,6 +12,11 @@ Bug fixes
* Cope with non-utf8 characters in paths when importing.
(Jelmer Vernooij, #838980)
+Features
+--------
+
+* New option --rewrite-tag-names for 'bzr fast-export'. (Alex Usov, #872601)
+
0.11 2011-08-22
Bug fixes
diff --git a/cmds.py b/cmds.py
index 362113e..d5aedd6 100644
--- a/cmds.py
+++ b/cmds.py
@@ -578,10 +578,11 @@ class cmd_fast_export(Command):
future once the feature names and definitions are formally agreed
to by the broader fast-import developer community.
- Git has much stricter naming rules for tags and fast-export --plain
- will skip tags which can't be imported into git. If you want to rename
- these tags use --rewrite-tag-names.
-
+ Git has stricter naming rules for tags and fast-export --plain
+ will skip tags which can't be imported into git. To replace characters
+ unsupported in git with an underscore instead, specify
+ --rewrite-tag-names.
+
:Examples:
To produce data destined for import into Bazaar::
@@ -629,7 +630,8 @@ class cmd_fast_export(Command):
help="Exclude metadata to maximise interoperability."
),
Option('rewrite-tag-names',
- help="Rewrite invalid tag names in plain mode."
+ help="Replace characters invalid in git with '_'"
+ " (plain mode only).",
),
]
encoding_type = 'exact'
diff --git a/exporter.py b/exporter.py
index cad3241..7848c52 100644
--- a/exporter.py
+++ b/exporter.py
@@ -151,13 +151,13 @@ class BzrFastExporter(object):
"""Export branch data in fast import format.
:param plain_format: if True, 'classic' fast-import format is
- used without any extended features; if False, the generated
- data is richer and includes information like multiple
- authors, revision properties, etc.
-
- :param rewrite_tags: if True tag names will be rewritten to be
- git-compatible. Otherwise tags which aren't valid for git will
- be skiped.
+ used without any extended features; if False, the generated
+ data is richer and includes information like multiple
+ authors, revision properties, etc.
+ :param rewrite_tags: if True and if plain_format is set, tag names
+ will be rewritten to be git-compatible.
+ Otherwise tags which aren't valid for git will be skipped if
+ plain_format is set.
"""
self.source = source
self.outf = _get_output_stream(destination)